@@ -1,5 +1,4 @@
-# Copyright (C) 2005  Warp Networks S.L., DBS Servicios Informaticos S.L.
-# Copyright (C) 2007  Warp Networks S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -39,7 +38,7 @@ use EBox::Validate qw(:all);
 use EBox::Model::ModelManager;
 use EBox::Model::CompositeManager;
 
-use EBox::Sudo qw(:all);
+use EBox::Sudo;
 use EBox::NetWrappers qw(:all);
 use EBox::Service;
 use EBox::DHCPLogHelper;
@@ -63,17 +62,18 @@ use EBox::DHCP::Model::RangeInfo;
 use EBox::DHCP::Model::RangeTable;
 use EBox::DHCP::Model::ThinClientOptions;
 use Net::IP;
-use HTML::Mason;
 use Error qw(:try);
 use Perl6::Junction qw(any);
 use Text::DHCPLeases;
 
 # Module local conf stuff
-use constant DHCPCONFFILE => "/etc/dhcp3/dhcpd.conf";
-use constant LEASEFILE => "/var/lib/dhcp3/dhcpd.leases";
-use constant PIDFILE => "/var/run/dhcpd.pid";
-use constant DHCP_SERVICE => "ebox.dhcpd3";
+use constant DHCPCONFFILE => ""; 
+use constant LEASEFILE => ""; 
+use constant PIDFILE => ""; 
+use constant APPARMOR_PROFILE => '/etc/apparmor.d/usr.sbin.dhcpd3.zentyal';
+use constant DHCP_SERVICE => "";
 use constant TFTP_SERVICE => "tftpd-hpa";
+use constant APPARMOR_SERVICE => '/etc/init.d/apparmor';
 
 use constant CONF_DIR => EBox::Config::conf() . 'dhcp/';
 use constant PLUGIN_CONF_SUBDIR => 'plugins/';
@@ -116,27 +116,47 @@ sub usedFiles
 		{
 		 'file' => DHCPCONFFILE,
 		 'module' => 'dhcp',
-         'reason' => 'dhcpd configuration file'
+                 'reason' => __x('{server} configuration file', server => 'dhcpd'),
 		}
 	       ];
 }
 
+# Method: actions
+#
+#	Override EBox::Module::Service::actions
+#
+sub actions
+{
+    return [
+        {
+            'action' => __x('Disable {server} init script', server => 'dhcpd'),
+            'reason' => __('Zentyal will take care of start and stop ' .
+                'the service'),
+            'module' => 'dhcp',
+        }
+    ];
+}
+
 # Method: enableActions
 #
-# 	Override EBox::Module::Service::enableActions
+#   Override EBox::Module::Service::enableActions
 #
 sub enableActions
 {
-    root(EBox::Config::share() . '/ebox-dhcp/ebox-dhcp-enable');
+    EBox::Sudo::root(EBox::Config::share() . '/ebox-dhcp/ebox-dhcp-enable');
 }
 
 # Method: _daemons
 #
-#	Override EBox::Module::Service::daemons
+# Overrides:
+#
+#   <EBox::Module::Service::daemons>
 #
 sub _daemons
 {
-    return [ { 'name' => DHCP_SERVICE } ];
+    return [
+        { 'name' => DHCP_SERVICE },
+       ];
 }
 
 # Method: _setConf
@@ -617,7 +637,7 @@ sub winsServer # (iface)
 
 # Method: staticRoutes
 #
-#	Get the static routes. It polls the eBox modules which
+#	Get the static routes. It polls the Zentyal modules which
 #	implements <EBox::DHCP::StaticRouteProvider>
 #
 # Returns:
@@ -1359,6 +1379,7 @@ sub widgets
         'dhcpleases' => {
             'title' => __("DHCP leases"),
             'widget' => \&dhcpLeasesWidget,
+            'order' => 5,
             'default' => 1
         }
     };
@@ -1374,6 +1395,7 @@ sub _setDHCPConf
 {
     my $self = shift;
 
+    # Write general configuration
     my $net = EBox::Global->modInstance('network');
     my $staticRoutes_r =  $self->staticRoutes();
 
@@ -1390,8 +1412,16 @@ sub _setDHCPConf
         push @params, ('dynamicDNSEnabled' => $dynamicDNSEnabled);
         push @params, ('keysFile' => $self->_keysFile());
     }
+    push(@params, ('pidFile' => PIDFILE));
 
     $self->writeConfFile(DHCPCONFFILE, "dhcp/dhcpd.conf.mas", \@params);
+
+    # Write apparmor profile if needed
+    if ((-f APPARMOR_SERVICE) and not (-f APPARMOR_PROFILE) and ($dynamicDNSEnabled)) {
+        $self->writeConfFile(APPARMOR_PROFILE, "dhcp/apparmor-dhcpd.profile.mas",
+                             [ ( 'keysFile'  => $self->_keysFile() ) ]);
+        EBox::Sudo::root(APPARMOR_SERVICE . ' restart');
+    }
 }
 
 # Method: _setTFTPDConf
@@ -1670,7 +1700,6 @@ sub _dynamicDNSEnabled # (ifacesInfo)
     }
 }
 
-
 # Configure the firewall rules to add
 # XXX maybe this is dead code?
 sub _configureFirewall {
